function [M, H] = read_diff_time_749 (path, side, style, srv, cli, ...
    irt, req_size, team)
%READ_DIFF_TIME_749   Read the latency between corresponding points in the MEAD infrastructure.
%   READ_DIFF_TIME_749 (path, side, style, srv, cli, irt, req_size, team) 
%   returns an matrix with the time differences (latency) 
%   between corresponding 'in' and 'out' timers. Each column in the matrix 
%   corresponds to a different host.
%
%   [M, H] = read_diff_time_749 (path, side, style, srv, cli, irt, req_size, team)
%   returns in M the latency information form all the clients from the 
%   corresponding experiment (each column in the matrix represents one
%   host). H is a cell array containig the host names that correspond to 
%   the columns of M.
%
%   path        = path to file
%   side        = 'cli'/'srv'
%   style       = 'ACTIVE'/'WARM_PASSIVE'
%   srv         = number of server replicas
%   cli         = number of clients
%   irt         = delay between requests (in usec)
%   req_size    = size of the request (actually, this is the size of the
%                 reply message)
%   team        = hostname
%
%   See also READ_TIMING_749

%   $Date: 2004/1/04 $


% Read the 'in' file
new_string = 'in';
[m_in, h_in] = read_timing_749 (path, new_string, side, style, srv, cli, ...
    irt, req_size, team);

% Sort host names alphabetically for matching in and out probes
[h_in, index] = sort(h_in);
m_in = m_in(:,index);

% Read the 'out' file
new_string = 'out';
[m_out, h_out] = read_timing_749 (path, new_string, side, style, srv, cli, ...
    irt, req_size, team);

[h_out, index] = sort(h_out);
m_out = m_out(:,index);

% Check if same hostnames
if (strcmp(h_in, h_out))
    % OK
else
    if (~isempty(h_in) || ~isempty(h_out))
        warning('FOR (team=%d rs=%d irt=%d cli=%d): hostnames are not the same!', ...
            team, req_size, irt, cli);
        h_in
        h_out
    end
    
    M = []; H = [];
    return
end

H = h_in;

% Match the sizes of the in and out probes
min_size = min([size(m_in,1) size(m_out,1)]);

% Compute the difference    
if (strcmp(side,'srv')),
    M = m_out(1:min_size, :) - m_in(1:min_size, :);
elseif (side=='cli'),
    M = m_in(1:min_size, :) - m_out(1:min_size, :);
end

if (~isempty(find(M<0)))
    warning ('FOR (team=%d side=%s rs=%d irt=%d cli=%d): negative time difference!', ...
            team, side, req_size, irt, cli);
end
